---
comments: true
title: Bump My Version
---

# Bump My Version

## Bump My Version's purpose is to

::: grid wide-gap
    ::: card-container horizontal depth-0
        ::: card-icon
            :fontawesome-solid-gear:
        ::: card-content
            ::: card-content-title
                Work as a part of an automated build system.
            Bump My Version works with automation workflows.

    ::: card-container horizontal depth-0
        ::: card-icon
            :fontawesome-solid-magnifying-glass:
        ::: card-content
            ::: card-content-title
                Search and replace data in project files
            Update the version and metadata in your files when you increment your version.

    ::: card-container horizontal depth-0
        ::: card-icon
            :fontawesome-solid-sliders:
        ::: card-content
            ::: card-content-title
                Manage your project's versioning
            - Increment and serialize version numbers
            - Parsing version numbers
            - Support SemVer, CalVer, and other versioning schemes

    ::: card-container horizontal depth-0
        ::: card-icon
            :fontawesome-solid-code-commit:
        ::: card-content
            ::: card-content-title
                Work with the project's source control system
            - Committing changes
            - Tagging releases
            - Reading version numbers from tags

## Jump to section

::: grid wide-gap

    ::: card-container

        ::: card-media

            ![Tutorials](assets/tutorial.jpg)

        ::: card-content

            [Tutorials](tutorials/getting-started.md)
            { .card-content-title }

            Follow along with our guides to learn how to use Bump My Version.

    ::: card-container

        ::: card-media

            ![Reference](assets/reference.jpg)

        ::: card-content

            [Reference](reference/)
            { .card-content-title }

            Consult the reference for specifics about the Bump My Version's configuration and commands.

    ::: card-container

        ::: card-media

            ![How-To's](assets/how-to.jpg)

        ::: card-content

            [How-To's](howtos/index.md)
            { .card-content-title }

            Need to get something done? Check out our how-to guides.

    ::: card-container

        ::: card-media

            ![Explanations](assets/explanations.jpg)

        ::: card-content

            [Explanations](explanation/index.md)
            { .card-content-title }

            Want to understand the library better? Read our explanations behind the design.
